@@ -18,7 +18,7 @@ class CouchBackend(object):
         try:
             user = self.db[user_id]
             if len(self.db.view(settings.COUCHDB_AUTH_VIEW, key=user.username, limit=1).rows):
-                return User(self.db[user_id], _db = self.db)
+                return User(user, _db = self.db)
             else:
                 return None
         except ResourceNotFound:
